@@ -8,7 +8,7 @@ from cPickle import *
 from struct import pack, unpack
 from contextlib import closing
 from itertools import ( chain, count, ifilterfalse, islice,
-                        izip, tee )
+                        izip, repeat, tee )
 from .log import warning
 
 """
